@@ -44,7 +44,9 @@ describe "Trocla::Format::X509" do
       expect(cert.public_key.n.num_bytes * 8).to eq(4096)
       expect((Date.parse(cert.not_after.localtime.to_s) - Date.today).to_i).to eq(365)
       # it's a self signed cert and NOT a CA
-      expect(verify(cert,cert)).to be false
+      # Change of behavior on openssl side: https://github.com/openssl/openssl/issues/15146
+      validates_self_even_if_no_ca = Gem::Version.new(%x{openssl version}.split(' ')[1]) > Gem::Version.new('1.1.1g')
+      expect(verify(cert,cert)).to be validates_self_even_if_no_ca
 
       v = cert.extensions.find{|e| e.oid == 'basicConstraints' }.value
       expect(v).to eq('CA:FALSE')
@@ -136,6 +138,11 @@ describe "Trocla::Format::X509" do
       expect(cert_str).not_to match(/-----BEGIN CERTIFICATE-----/)
       expect(cert_str).to match(/-----BEGIN RSA PRIVATE KEY-----/)
     end
+    it 'supports fetching only the publickey' do
+      pkey_str = @trocla.password('mycert', 'x509', cert_options.merge('render' => {'publickeyonly' => true }))
+      expect(pkey_str).not_to match(/-----BEGIN CERTIFICATE-----/)
+      expect(pkey_str).to match(/-----BEGIN PUBLIC KEY-----/)
+    end
     it 'supports fetching only the cert' do
       cert_str = @trocla.password('mycert', 'x509', cert_options.merge('render' => {'certonly' => true }))
       expect(cert_str).to match(/-----BEGIN CERTIFICATE-----/)
